package scalapi.jdk

import control.{Use, Evaluate}
import java.util.zip.{ZipEntry, ZipInputStream}
import scalapi.jdk.io.ZipInputStreams
import scala.concurrent.Future
import scalapi.jdk.concurrent.Futures.futureToValue
import scala.concurrent.duration._

object Implicits {

  // Concurrent

  implicit class RichFuture[T](future: Future[T]) {

    def getValue(implicit atMost: Duration = 5.seconds): T =
      futureToValue(future)(atMost)

  }

  // Control

  implicit def pimpAnyWithEvaluate[A](any: A) = new Evaluate.AnyPimp(any)

  implicit def pimpClosableWithUse[C <: {def close()}](closable: C) = new Use.ClosablePimp(closable)

  // IO

  implicit class RichZipInputStream(zipInputStream: ZipInputStream) {

    def mapEntries[T](entryHandler: ZipEntry => T): Seq[T] =
      ZipInputStreams.mapEntries(zipInputStream)(entryHandler)

    def forEachEntry(entryHandler: ZipEntry => Unit) {
      ZipInputStreams.forEachEntry(zipInputStream)(entryHandler)
    }

  }

}